===============
trove-dashboard
===============

.. _trove-dashboard_11.0.0.0b3:

11.0.0.0b3
==========

.. _trove-dashboard_11.0.0.0b3_Upgrade Notes:

Upgrade Notes
-------------

.. releasenotes/notes/django20-support-fd32553ded354e56.yaml @ ddaf10204aec8a21393a9ca19e819df3ea1a6e42

- Django 2.0 is now supported and Django versions older than 1.11 are no
  longer supported aligning with Django versions supported by horizon.
  Note that Django 1.11 is still supported and this is the only version
  when you use python 2.7.

